@@ -12,7 +12,7 @@ from common.variables import LOGGING_LEVEL
 client_formatter = logging.Formatter('%(asctime)s %(levelname)s %(filename)s %(message)s')
 
 # Подготовка имени файла для логирования
-path = os.getcwd()
+path = os.path.dirname(os.path.abspath(__file__))
 path = os.path.join(path, 'client.log')
 
 # создаём потоки вывода логов
@@ -23,7 +23,7 @@ log_file = logging.FileHandler(path, encoding='utf8')
 log_file.setFormatter(client_formatter)
 
 # создаём регистратор и настраиваем его
-logger = logging.getLogger('client')
+logger = logging.getLogger('client_dist')
 logger.addHandler(steam)
 logger.addHandler(log_file)
 logger.setLevel(LOGGING_LEVEL)
