@@ -14,7 +14,7 @@ from common.variables import LOGGING_LEVEL
 server_formatter = logging.Formatter('%(asctime)s %(levelname)s %(filename)s %(message)s')
 
 # Подготовка имени файла для логирования
-path = os.getcwd()
+path = os.path.dirname(os.path.abspath(__file__))
 path = os.path.join(path, 'server.log')
 
 # создаём потоки вывода логов
@@ -25,7 +25,7 @@ log_file = logging.handlers.TimedRotatingFileHandler(path, encoding='utf8', inte
 log_file.setFormatter(server_formatter)
 
 # создаём регистратор и настраиваем его
-logger = logging.getLogger('server')
+logger = logging.getLogger('server_dist')
 logger.addHandler(steam)
 logger.addHandler(log_file)
 logger.setLevel(LOGGING_LEVEL)
