@@ -1,3 +1,4 @@
+import sys
 import os
 import argparse
 import logging
@@ -14,7 +15,7 @@ from PyQt5.QtWidgets import QApplication
 from PyQt5.QtCore import Qt
 
 # Инициализация логирования сервера.
-logger = logging.getLogger('server')
+logger = logging.getLogger('server_dist')
 
 
 @log
@@ -38,8 +39,8 @@ def arg_parser(default_port, default_address):
 def config_load():
     """Парсер конфигурационного ini файла."""
     config = configparser.ConfigParser()
-    dir_path = os.getcwd()
-    config.read(f"{dir_path}/{'server+++.ini'}")
+    dir_path = os.path.dirname(os.path.realpath(__file__))
+    config.read(f"{dir_path}/{'server_dist+++.ini'}")
     # Если конфиг файл загружен правильно, запускаемся, иначе конфиг по
     # умолчанию.
     if 'SETTINGS' in config:
